@@ -1,7 +1,7 @@
 # Copyright (C) 2009 David Sauve, Trapeze
 
 __author__ = 'David Sauve'
-__version__ = (1, 1, 1, 'beta')
+__version__ = (1, 1, 3, 'beta')
 
 import time
 import datetime
@@ -364,7 +364,7 @@ class SearchBackend(BaseSearchBackend):
         if not end_offset:
             end_offset = database.get_doccount()
         
-        matches = enquire.get_mset(start_offset, (end_offset - start_offset))
+        matches = enquire.get_mset(start_offset, end_offset)
         
         for match in matches:
             app_label, module_name, pk, model_data = pickle.loads(match.document.get_data())
@@ -375,7 +375,7 @@ class SearchBackend(BaseSearchBackend):
                     )
                 }
             results.append(
-                SearchResult(app_label, module_name, pk, match.weight, **model_data)
+                SearchResult(app_label, module_name, pk, match.percent, weight=match.weight, **model_data)
             )
         
         if facets:
@@ -471,7 +471,7 @@ class SearchBackend(BaseSearchBackend):
             document = match.get_document()
             app_label, module_name, pk, model_data = pickle.loads(document.get_data())
             results.append(
-                SearchResult(app_label, module_name, pk, match.weight, **model_data)
+                SearchResult(app_label, module_name, pk, match.percent, weight=match.weight, **model_data)
             )
         
         return {
@@ -795,16 +795,17 @@ class SearchQuery(BaseSearchQuery):
     It acts as an intermediary between the ``SearchQuerySet`` and the
     ``SearchBackend`` itself.
     """
-    def __init__(self, backend=None):
+    def __init__(self, backend=None, site=None):
         """
         Create a new instance of the SearchQuery setting the backend as
         specified.  If no backend is set, will use the Xapian `SearchBackend`.
         
         Optional arguments:
             ``backend`` -- The ``SearchBackend`` to use (default = None)
+            ``site`` -- The site to use (default = None)
         """
         super(SearchQuery, self).__init__(backend=backend)
-        self.backend = backend or SearchBackend()
+        self.backend = backend or SearchBackend(site=site)
     
     def run(self, spelling_query=None):
         try:
